@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4101';
+our $VERSION = '0.4102';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -622,7 +622,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4101
+version 0.4102
 
 =head1 SYNOPSIS
 
@@ -667,9 +667,8 @@ version 0.4101
     $d->open_hh => [ '1111' ],
     $d->snare   => [ '0101' ],
     $d->kick    => [ '1010' ],
- ) for 1 .. $d->bars - 1;
+ ) for 1 .. $d->bars;
 
- # Add a fill to the end of the phrase!
  $d->add_fill('...');
 
  print 'Count: ', $d->counter, "\n";
@@ -1051,9 +1050,9 @@ If a C<duration> is provided, this will be used for each pattern
             $self->kick    => '00000000',
           };
       },
-      $d->open_hh => [ ('11111111') x $d->bars ],  # example phrase
-      $d->snare   => [ ('0101') x $d->bars ],      # "
-      $d->kick    => [ ('1010') x $d->bars ],      # "
+      $d->open_hh => [ '11111111' ],  # example phrase
+      $d->snare   => [ '0101' ],      # "
+      $d->kick    => [ '1010' ],      # "
   );
 
 Add a fill to the beat pattern.  That is, replace the end of the given
@@ -1061,8 +1060,6 @@ beat-string phrase with a fill.  The fill is given as the first
 argument and should be a coderef that returns a hashref.  The default
 is a three-note, eighth-note snare fill.
 
-* This method is not right at all and is still in development.
-
 =head2 euclidean
 
   $pattern = $d->euclidean($p, $n);
